%commit = (
    "0b600cf5b896549df66a1ee2d0a625aa301011d4" => {
        body    => "",
        extra   => "",
        parent  => [],
        subject => "empty tree",
        tree    => "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
    },
    "0bd057751e8ff20ad6b535fd69c6c90686f9fc95" => {
        body    => "",
        extra   => "",
        parent  => [ "37f27fcfaac3b4aa5fbc357266dea6d0e2eb7c99" ],
        subject => "add the README",
        tree    => "2d737f2ef36761c200278a20cb1cc098e425ecf8"
    },
    "328573de72ce45434f0e434979eebfd80913089c" => {
        body    => "",
        extra   => "",
        parent  => [ "a40b286101372efd353cfcbf2080c4ab3c33d80d" ],
        subject => "hall\303\263 (is)",
        tree    => "1840015fc84bf133760c966eed4c1b4047ea657a"
    },
    "36f0b6bd5c4cc36bcda5cdff1922400a774e75c4" => {
        body  => "",
        extra => "",
        gpgsig =>
            "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoAAAoJEOX2RRt2IcQDoTQH/0nbvPIkXkYTT57G6btIE5z4\nyiULSN7VNEqcdoF+b30nn//3Jgx+GSGq5VWQDh24rJlQz+VdiSY5pbWs0ErVYNPI\n5i4MuW0xq2Iwjn0dYECVYPspD0jWq5zNwV/5zZvul2PqP2BWwP8SVe27K+XODOME\nzRvIyyGeCRPpEo/y8DnmY9WepXBe/Wr62gOwKxQYHJue4I9+LJSFHRJZaYSQsJJd\ng514yeUHO9i5evSMZd3VNTI5RzzFrGlZe+vtRkljku6aPcflaseMftLl8ILwO8Fl\nwaVYH3VYQ12H/iivtCRz2K6t6R2ArSji3cnylaBFqvmvz/u8RReLk5+3EEkyrug=\n=24Ef\n-----END PGP SIGNATURE-----",
        parent  => [ "d63a617ef79e58dc5afb4ac10e90c4de48269d60" ],
        subject => "hej (da)",
        tree    => "7b8f01341e59251bbf067b1001cdd12f44c36847"
    },
    "37f27fcfaac3b4aa5fbc357266dea6d0e2eb7c99" => {
        body  => "",
        extra => "",
        gpgsig =>
            "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDRVcH/igME/Y16gcdUmRXfQ+b2Txb\nhgQ7c8aJBzXnmnfeIsZ/K5eZ/LEzrZrifykKSlZcqVfvfotObmZ+bXh6Kaw/ZA5q\nRSalPpAtOQVzebD6nq9a5O0SMeAeJygRJVJls7jDIC7W1vHWlV05d6W63z7/3fa8\nAZn22UHnCU+t6Ah90k6vbOWfyzcvHCE5/9tnL7bRCmdGZRMvMTbSR/TlSo85a02l\nHDdH5/OkPeURZuZmcAsJDRSHVRUgsdbBriewK9nqxsE3gSRrqaf5h/GzK1UzIWUS\nmusVTrhXxvbfFegwONMaFJWvTcbFgVGQ1jhCWZHCTs3JoQZgcSuIiwB+Xs+3Mo0=\n=SDCo\n-----END PGP SIGNATURE-----",
        mergetag => [
            "object e79061494b97204901f40b501c61eb8d161db5c1\ntype commit\ntag v1.0.3\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDH0gH/0ZBTlxCQDY23BJaxYXApNKt\n3IHFTVrzL2GiXXtkY9Xo376LQuPiNfcuXReV1Taah2WryrtKRtrX6T1G5UbfInk5\nubTpEBOcRmObIlD9E4np0WBr57QJ7ilib1XnI4gyGoHM6ZY7RgyvIcQor4g1t1C3\na62L8xPgOuWIr5493AqrmNp2pqzjDV4swNQN6nPxmZjTpwoXnSjjHp8hap23C+k/\nsYPRZ2pL68+jCCjwp4AcDYgFxNygUWGHtL6OQGEjvzimxkLUnQNd8xFnPsKRs9uc\n3iKp1m4nk+p9fMaj6BJPy8ElNUIWMA/4GpZJmcru4yZj3wlH5GB8uLh1kzoW0ds=\n=A8XS\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "4c9c4bb1f4c980a003dfd8fdfe567dfb36e3d641",
            "e79061494b97204901f40b501c61eb8d161db5c1"
        ],
        subject => "buen d\303\255a (es)",
        tree    => "7b8f01341e59251bbf067b1001cdd12f44c36847"
    },
    "4c9c4bb1f4c980a003dfd8fdfe567dfb36e3d641" => {
        body  => "",
        extra => "",
        gpgsig =>
            "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDjLsH/3/WpxtKV6TjFEizFWmg6hMQ\njV28z9nydG253NCw1LCYDccWJqHAer0aWHUQqv/o8JS/rm7k6yBmWsGaZenwNQ2J\n2ID0f61Z29plzt1aNf5KbB5Y+XAyXGeNa1WdKP3Se3qgEVLq1RLtEcjBvWezJzBt\nCU3bw0taboHYnEiwF8SjAdAvHxbphuXZPT9Evh+SL4G6Aab3YjNq7BVoKtQo6nhH\nTsHO7N+1YuSzkckUaTGePJEAiDn6QIpVkyVlo/Fv/g5URFXTw+ZVFIwaBozD0QoE\n+EAEr/niz3k8tshgPLxmvgtAi2Fr0+RspjnCxxHa/LfYcl/somVzLoQv6MXArQo=\n=dkPI\n-----END PGP SIGNATURE-----",
        mergetag => [
            "object 990cf16a3a5a894b6558c6a6d7be1845ec1ca796\ntype commit\ntag v1.0.2\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDYjEH/25sFxu38z7/bsw+7YSmp0sP\nUYZtzUl9yoK0diseTxScl02NZh1KrauP7m2Qax+psnmIbnZT00iD3bHODxoX6xtj\nSvKSeAsvAdJUZW/wrrEdc5ngcAnayMrEnv1lEt1cqJhFCqkBv/3m87GRCsrFuXYE\nbNvS7YNhSzQuWWqCon0lJZlaKjwJGLK+G+nsoETw0Bc14Bo3AcHv9jl2b2gKmyFU\nGd7Chfk8AyTcGyrSRk52TCCUleuzZEGt/+yM/FB66olzB9U8bZC9ee1CoYvt+kCz\nW3ReZ/3tYoXGh/A/7Jyc9+I5P/8NxbTVW9Ac4UH94/g+0uxInV6WNZ0x7mqJMf4=\n=ZfZZ\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "b0154ffe6cf058d39ae9f218eb3d2b61b6771008",
            "990cf16a3a5a894b6558c6a6d7be1845ec1ca796"
        ],
        subject => "bom dia",
        tree    => "7b8f01341e59251bbf067b1001cdd12f44c36847"
    },
    "525b03e1ced52027a7128df8892dea06ca3d007b" => {
        body   => "",
        extra  => "",
        parent => [ "328573de72ce45434f0e434979eebfd80913089c" ],
        subject =>
            "\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257 (ja)",
        tree => "822aed1f11e71b48d14c899d209b0dca92a08ec8"
    },
    "8aca504d7523cb4b3bc3f67c7c4502569f247dc0" => {
        body    => "",
        extra   => "",
        parent  => [],
        subject => "hello (en)",
        tree    => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
    },
    "990cf16a3a5a894b6558c6a6d7be1845ec1ca796" => {
        body  => "",
        extra => "",
        gpgsig =>
            "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDzFgH/2cCQpbJftnjtZrTONA1Zs9B\nDsR0g/gyUWJeCWIpn0583BBDMZTv7vMeDKTLbSRjhxteaBy5SL8KZ/L8tDyaavGp\njSv2sBroDnlbxJNhXeBJzvT/L9p41uyFsJ9CV3mxJXhQVSqRwsbWoBiYM6EXwsX/\nupk2cZ2DPhDpmtBfvhZNBUWtHMRak7KrLv0dSoaVQap2pHk7hAKk2xb+kuarp9vy\n3rmFWW2t9y4meNQMxBbAamEsXkPNSlzK21y9lTlDbZ6hASEMC4Y1ZsyeefM/fxqY\nOsFRotnAtcTRUsW+33fygR5mFYO6rhOz8WHxqEHyZIs4uGYKLrqx0je9oPNse7E=\n=Obaq\n-----END PGP SIGNATURE-----",
        parent  => [ "525b03e1ced52027a7128df8892dea06ca3d007b" ],
        subject => "ol\303\241 (pt)",
        tree    => "33a90fc1da2f84bfc394fa886a3d70ae534dc03f"
    },
    a40b286101372efd353cfcbf2080c4ab3c33d80d => {
        body    => "",
        extra   => "",
        parent  => [ "bab4b9852ecc278a7913a1413fb43575846b8727" ],
        subject => "g\303\263\303\260ur dagur (is)",
        tree    => "b090e309a779f2ea76260d10abd027b08fb36362"
    },
    b0154ffe6cf058d39ae9f218eb3d2b61b6771008 => {
        body     => "",
        extra    => "",
        mergetag => [
            "object 525b03e1ced52027a7128df8892dea06ca3d007b\ntype commit\ntag v1.0.1\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\n\303\243\302\201\302\223\303\243\302\202\302\223\303\243\302\201\302\253\303\243\302\201\302\241\303\243\302\201\302\257\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDWxwH/RRmTrYw3kXVJ+yuTWq1/d3J\nI9pnIJwRqx8IvooAZyrvauk7X1xR5DVLuiJ+PFpSgWH2LcvtDWcVAsOMroh9QR8M\nc3USKuK5MP61XJoNW1PXXlCKjtrqP8+cMGwcP+IwqfLKfRAPuMrF4yiSPI1v1jRe\niaNkSfbYjM1LZhBsoFexF3YxrE1pA3msPYPLk6COVQDIHzPTyWiO8STQVLXt82ON\nSSdytIDKtpE825Ctz+6rPbpZRZS/3/CcwU1gFHwChFZl33tu16Gqzx5nAvyR623t\ne0nojz+Wwklt47+XPBdoD59SswEVaAJsq8tSkuNc5lseFzwHGiZYEHUc1EmTZBE=\n=OhCX\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "ffa480eec8352743ca5d2df53cdd77d6f78f277b",
            "525b03e1ced52027a7128df8892dea06ca3d007b"
        ],
        subject => "dobr\303\275 den (cs)",
        tree    => "7b8f01341e59251bbf067b1001cdd12f44c36847"
    },
    bab4b9852ecc278a7913a1413fb43575846b8727 => {
        body   => "",
        extra  => "",
        parent => [
            "8aca504d7523cb4b3bc3f67c7c4502569f247dc0",
            "0b600cf5b896549df66a1ee2d0a625aa301011d4"
        ],
        subject => "Merge branch 'slave'",
        tree    => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
    },
    d63a617ef79e58dc5afb4ac10e90c4de48269d60 => {
        body   => "",
        extra  => "",
        parent => [ "bab4b9852ecc278a7913a1413fb43575846b8727" ],
        subject =>
            "\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257 (ja)",
        tree => "51827db31da3d816058b613f19c971e5c4fa6f16"
    },
    e79061494b97204901f40b501c61eb8d161db5c1 => {
        body    => "",
        extra   => "",
        parent  => [ "990cf16a3a5a894b6558c6a6d7be1845ec1ca796" ],
        subject => "",
        tree    => "524a684865d9b37e0a7236df14ccde01501f063d"
    },
    ee142e881f827dbb001faef939eeedf83afbddc5 => {
        body  => "",
        extra => "",
        gpgsig =>
            "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQD7okH/2CjprHLJfMARB9AngVt9rFy\nDqcg8YEx48SpnuQKku/rDcisXJISSxlChGqG9tvekVqj9KEO5kkbJ6A95REEOH97\nVmSigfhQURxoi66z/OK9sExAqlUCDpTvAcZVA90D6G6iCf4lHZyfHKy1eCSXouhf\nOrl1u+5O3Bd3VBcjP850DYwHVmHByCz5003UlA02b95MGCx9HVfxh/JAjY7NYb5v\npmJvW3rgtud4vmadCYA7OXlLLgsuVYPAIJ2df6n6ttJQ9ALGtH7bh7MRHGsb8q4t\nRfxLloKtxqgSQH5msHyGY/vCCJ5LZ5Hv0ln5qJ4jSLlxo72LGTSpCwDw631tp+I=\n=xRDy\n-----END PGP SIGNATURE-----",
        mergetag => [
            "object ffa480eec8352743ca5d2df53cdd77d6f78f277b\ntype commit\ntag v1.1.0\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDarEH/i7yyczjprGBqQcfV9EMRBTB\nExoh8HYquxb+kTvrykUC3VJhBJ9vkJOlYWIVsBuCeo28iOSfa4pqfdCjXu6LNejq\nldwi+oKNi4UFFTZZB/w1PFKF4s+SVcDx7Uyh4AWz6f9E/o6mGMTkCH7Vrl6AbETq\n0dN84I8QvnJtjyXDNt3sjdxiiFsdlbrp3DJkV1s7KqsPJWkVSva0YyztFZnt4mP2\neMuealUSdVsVg9TF0qvWENEzS4GQTXe2aUOm9KaAuonVv4QzlDXzSz/Ra2Yl4jsW\nns3nVAb7AQdl3oHpFQFQ2tZGYPKRWrItflt9cuZRU0oePkbIVPHfJ94yIcCOE08=\n=44Jj\n-----END PGP SIGNATURE-----",
            "object 990cf16a3a5a894b6558c6a6d7be1845ec1ca796\ntype commit\ntag v1.0.2\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDYjEH/25sFxu38z7/bsw+7YSmp0sP\nUYZtzUl9yoK0diseTxScl02NZh1KrauP7m2Qax+psnmIbnZT00iD3bHODxoX6xtj\nSvKSeAsvAdJUZW/wrrEdc5ngcAnayMrEnv1lEt1cqJhFCqkBv/3m87GRCsrFuXYE\nbNvS7YNhSzQuWWqCon0lJZlaKjwJGLK+G+nsoETw0Bc14Bo3AcHv9jl2b2gKmyFU\nGd7Chfk8AyTcGyrSRk52TCCUleuzZEGt/+yM/FB66olzB9U8bZC9ee1CoYvt+kCz\nW3ReZ/3tYoXGh/A/7Jyc9+I5P/8NxbTVW9Ac4UH94/g+0uxInV6WNZ0x7mqJMf4=\n=ZfZZ\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "0b600cf5b896549df66a1ee2d0a625aa301011d4",
            "ffa480eec8352743ca5d2df53cdd77d6f78f277b",
            "990cf16a3a5a894b6558c6a6d7be1845ec1ca796"
        ],
        subject => "buon giorno (it)",
        tree    => "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
    },
    f90274dc279ce4e2376ac10afa6528dac7f83657 => {
        body =>
            "# tag 'v1.1.0'\nsigned tag\n\n# gpg: Signature made Sat Nov  2 23:17:37 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n\n# tag 'v1.0.1'\n\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257\n\n# gpg: Signature made Sat Nov  2 23:17:37 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n",
        extra    => "",
        mergetag => [
            "object ffa480eec8352743ca5d2df53cdd77d6f78f277b\ntype commit\ntag v1.1.0\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDarEH/i7yyczjprGBqQcfV9EMRBTB\nExoh8HYquxb+kTvrykUC3VJhBJ9vkJOlYWIVsBuCeo28iOSfa4pqfdCjXu6LNejq\nldwi+oKNi4UFFTZZB/w1PFKF4s+SVcDx7Uyh4AWz6f9E/o6mGMTkCH7Vrl6AbETq\n0dN84I8QvnJtjyXDNt3sjdxiiFsdlbrp3DJkV1s7KqsPJWkVSva0YyztFZnt4mP2\neMuealUSdVsVg9TF0qvWENEzS4GQTXe2aUOm9KaAuonVv4QzlDXzSz/Ra2Yl4jsW\nns3nVAb7AQdl3oHpFQFQ2tZGYPKRWrItflt9cuZRU0oePkbIVPHfJ94yIcCOE08=\n=44Jj\n-----END PGP SIGNATURE-----",
            "object 525b03e1ced52027a7128df8892dea06ca3d007b\ntype commit\ntag v1.0.1\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\n\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoBAAoJEOX2RRt2IcQDWxwH/RRmTrYw3kXVJ+yuTWq1/d3J\nI9pnIJwRqx8IvooAZyrvauk7X1xR5DVLuiJ+PFpSgWH2LcvtDWcVAsOMroh9QR8M\nc3USKuK5MP61XJoNW1PXXlCKjtrqP8+cMGwcP+IwqfLKfRAPuMrF4yiSPI1v1jRe\niaNkSfbYjM1LZhBsoFexF3YxrE1pA3msPYPLk6COVQDIHzPTyWiO8STQVLXt82ON\nSSdytIDKtpE825Ctz+6rPbpZRZS/3/CcwU1gFHwChFZl33tu16Gqzx5nAvyR623t\ne0nojz+Wwklt47+XPBdoD59SswEVaAJsq8tSkuNc5lseFzwHGiZYEHUc1EmTZBE=\n=OhCX\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "bab4b9852ecc278a7913a1413fb43575846b8727",
            "ffa480eec8352743ca5d2df53cdd77d6f78f277b",
            "525b03e1ced52027a7128df8892dea06ca3d007b"
        ],
        subject => "Merge tags 'v1.1.0' and 'v1.0.1' into mergetags",
        tree    => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
    },
    ffa480eec8352743ca5d2df53cdd77d6f78f277b => {
        body =>
            "signed tag\n\n# gpg: Signature made Sat Nov  2 23:17:36 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n",
        extra    => "",
        mergetag => [
            "object 328573de72ce45434f0e434979eebfd80913089c\ntype commit\ntag v1.0.0\ntagger Example Committer <committer\@example.com> 1383430656 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSdXoAAAoJEOX2RRt2IcQDTk4H/2Mff8SUPQoII5PuqcTUObHC\ndJNCr8oVV6VMM/AliFjKPNXKY8eA1PEvya101uptzlxjey6jagScVAQNWnmjWFiQ\nDQR98uOYkWpwrCHmyQnv9/rI466nNdehMyk2YBSXx6FtPEfSZCBNQLvahxqsSYRJ\n8PZlrcdj9v7temqaAvI/Q5ul8+MH3SyeA/W2Jf8l/c1cbnAGICjY8dNoZ9x7o24E\ngdQT1bxIvMD6CG8iPpHYnKGcSQqGHxOzdt+zM6PlAmiCV2IfgXJ7SiB0GApmsReu\nP0OSNx3XSUL91fzEhbv95Gbc09xrp8IckuN5UpEH06p6sw1Uhrms9mbsJVPXDSE=\n=z3Cb\n-----END PGP SIGNATURE-----"
        ],
        parent => [
            "36f0b6bd5c4cc36bcda5cdff1922400a774e75c4",
            "328573de72ce45434f0e434979eebfd80913089c"
        ],
        subject => "Merge tag 'v1.0.0'",
        tree    => "7b8f01341e59251bbf067b1001cdd12f44c36847"
    }
);
